==> qcad-3.21.2.3.tgz: lib/qcad/ts/qcadgui_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Anpassad</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Ogiltig</translation>
    </message>
</context>
</TS>

==> qcad-3.23.0.0.tgz: lib/qcad/ts/qcadgui_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Anpassad</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Raster</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Slut</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>På objekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Vinkelrät</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangentiell</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centrum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Mitt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Skärningspunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referens</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+172"/>
        <source>Invalid</source>
        <translation>Ogiltig</translation>
    </message>
</context>
</TS>
